pub struct CredentialStore { /* private fields */ }Expand description
Credential store for all configured routes.
Implementations
Sourceimpl CredentialStore
impl CredentialStore
Sourcepub fn load(routes: &[RouteConfig]) -> Result<Self>
pub fn load(routes: &[RouteConfig]) -> Result<Self>
Load credentials for all configured routes from the system keystore.
Routes without a credential_key are skipped (no credential injection).
Returns an error if any configured credential fails to load.
Sourcepub fn get(&self, prefix: &str) -> Option<&LoadedCredential>
pub fn get(&self, prefix: &str) -> Option<&LoadedCredential>
Get a credential for a route prefix, if configured.